@@ -3,7 +3,6 @@
 // Copyright (c) Contributors to the OpenEXR Project.
 //
 
-
 #ifndef INCLUDED_IMF_ZIP_COMPRESSOR_H
 #define INCLUDED_IMF_ZIP_COMPRESSOR_H
 
@@ -21,41 +20,29 @@
 
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_ENTER
 
-
-class ZipCompressor: public Compressor
+class ZipCompressor : public Compressor
 {
-  public:
-
-    ZipCompressor (const Header &hdr, 
-                   size_t maxScanLineSize,
-                   size_t numScanLines);
+public:
+    ZipCompressor (
+        const Header& hdr, size_t maxScanLineSize, size_t numScanLines);
 
     virtual ~ZipCompressor ();
 
     virtual int numScanLines () const;
 
-    virtual int	compress (const char *inPtr,
-			  int inSize,
-			  int minY,
-			  const char *&outPtr);
+    virtual int
+    compress (const char* inPtr, int inSize, int minY, const char*& outPtr);
 
-    virtual int	uncompress (const char *inPtr,
-			    int inSize,
-			    int minY,
-			    const char *&outPtr);
-  private:
+    virtual int
+    uncompress (const char* inPtr, int inSize, int minY, const char*& outPtr);
 
-    int		_maxScanLineSize;
-    int		_numScanLines;
-    char *	_outBuffer;
-    Zip     _zip;
+private:
+    int   _maxScanLineSize;
+    int   _numScanLines;
+    char* _outBuffer;
+    Zip   _zip;
 };
 
-
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_EXIT
 
-
-
-
-
 #endif
